@@ -11,10 +11,10 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2006 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2009 Live Networks, Inc.  All rights reserved.
 // AC3 Audio RTP Sources
 // Implementation
 
@@ -71,7 +71,7 @@ Boolean AC3AudioRTPSource
 
   resultSpecialHeaderSize = 2;
   return True;
-}    
+}
 
 char const* AC3AudioRTPSource::MIMEtype() const {
   return "audio/AC3";
