@@ -11,10 +11,10 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2009 Live Networks, Inc.  All rights reserved.
 // H.263+ Video RTP Sources
 // Implementation
 
@@ -34,7 +34,7 @@ H263plusVideoRTPSource
 			 unsigned rtpTimestampFrequency)
   : MultiFramedRTPSource(env, RTPgs,
 			 rtpPayloadFormat, rtpTimestampFrequency),
-  fNumSpecialHeaders(0), fSpecialHeaderBytesLength(0) {  
+  fNumSpecialHeaders(0), fSpecialHeaderBytesLength(0) {
 }
 
 H263plusVideoRTPSource::~H263plusVideoRTPSource() {
@@ -62,7 +62,7 @@ Boolean H263plusVideoRTPSource
     ++expectedHeaderSize;
     if (packetSize < expectedHeaderSize) return False;
   }
-  
+
   if (PLEN > 0) {
     // There's an extra picture header at the end:
     expectedHeaderSize += PLEN;
