@@ -11,10 +11,10 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2006 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2009 Live Networks, Inc.  All rights reserved.
 // Author Bernhard Feiten
 // A filter that breaks up an H.263plus video stream into frames.
 // Based on MPEG4IP/mp4creator/h263.c
@@ -104,10 +104,10 @@ unsigned H263plusVideoStreamParser::parse(u_int64_t & currentDuration)
       // Parse 1 frame
       // For the first time, only the first frame's header is returned.
       // The second time the full first frame is returned
-      frameSize = parseH263Frame(); 
+      frameSize = parseH263Frame();
 
       currentDuration = 0;
-      if ((frameSize > 0)){ 
+      if ((frameSize > 0)){
          // We were able to acquire a frame from the input.
 
          // Parse the returned frame header (if any)
@@ -129,6 +129,8 @@ unsigned H263plusVideoStreamParser::parse(u_int64_t & currentDuration)
          //    if (h263Bitrates)
          //GetMaxBitrate(&fMaxBitrateCtx, frameSize, prevTrDifference);
          //prevTrDifference = trDifference;
+
+	 setParseState(); // Needed for the parsing process in StreamParser
       }
    } catch (int /*e*/) {
 #ifdef DEBUG
@@ -137,14 +139,12 @@ unsigned H263plusVideoStreamParser::parse(u_int64_t & currentDuration)
       frameSize=0;
    }
 
-   setParseState(); // Needed for the parsing process in StreamParser
-
    return frameSize;
 }
 
 
 ///////////////////////////////////////////////////////////////////////////////
-// parseH263Frame derived from LoadNextH263Object of MPEG4IP 
+// parseH263Frame derived from LoadNextH263Object of MPEG4IP
 // - service routine that reads a single frame from the input file.
 // It shall fill the input buffer with data up until - and including - the
 // next start code and shall report back both the number of bytes read and a
@@ -169,11 +169,11 @@ int H263plusVideoStreamParser::parseH263Frame( )
    u_int8_t * bufferIndex = fTo;
    // The buffer end which will allow the loop to leave place for
    // the additionalBytesNeeded
-   u_int8_t * bufferEnd = fTo + fMaxSize - ADDITIONAL_BYTES_NEEDED - 1;	
+   u_int8_t * bufferEnd = fTo + fMaxSize - ADDITIONAL_BYTES_NEEDED - 1;
 
    memcpy(fTo, fNextHeader, H263_REQUIRE_HEADER_SIZE_BYTES);
    bufferIndex += H263_REQUIRE_HEADER_SIZE_BYTES;
-   
+
 
    // The state table and the following loop implements a state machine enabling
    // us to read bytes from the file until (and inclusing) the requested
