@@ -336,7 +336,7 @@ char* RTSPClient::describeURL(char const* url, Authenticator* authenticator,
 	  char* ptr = &firstLine[bytesRead];
 	  int bytesRead2 = readSocket(envir(), fInputSocketNum, (unsigned char*)ptr,
 				      numExtraBytesNeeded, fromAddress);
-	  if (bytesRead2 < 0) break;
+	  if (bytesRead2 <= 0) break;
 	  ptr[bytesRead2] = '\0';
 	  if (fVerbosityLevel >= 1) {
 	    envir() << "Read " << bytesRead2 << " extra bytes: "
@@ -1636,7 +1636,7 @@ Boolean RTSPClient::getMediaSessionParameter(MediaSession& /*session*/,
 	  char* ptr = &firstLine[bytesRead];
 	  int bytesRead2 = readSocket(envir(), fInputSocketNum, (unsigned char*)ptr,
 				      numExtraBytesNeeded, fromAddress);
-	  if (bytesRead2 < 0) break;
+	  if (bytesRead2 <= 0) break;
 	  ptr[bytesRead2] = '\0';
 	  if (fVerbosityLevel >= 1) {
 	    envir() << "Read " << bytesRead2 << " extra bytes: "
@@ -1707,7 +1707,7 @@ Boolean RTSPClient::teardownMediaSession(MediaSession& session) {
       // Get the response from the server:
       unsigned bytesRead; unsigned responseCode;
       char* firstLine; char* nextLineStart;
-      if (!getResponse("TEARDOWN", bytesRead, responseCode, firstLine, nextLineStart)) break;
+      getResponse("TEARDOWN", bytesRead, responseCode, firstLine, nextLineStart); // ignore the response; from our POV, we're done
 
       // Run through each subsession, deleting its "sessionId":
       MediaSubsessionIterator iter(session);
@@ -1777,7 +1777,7 @@ Boolean RTSPClient::teardownMediaSubsession(MediaSubsession& subsession) {
       // Get the response from the server:
       unsigned bytesRead; unsigned responseCode;
       char* firstLine; char* nextLineStart;
-      if (!getResponse("TEARDOWN", bytesRead, responseCode, firstLine, nextLineStart)) break;
+      getResponse("TEARDOWN", bytesRead, responseCode, firstLine, nextLineStart); // ignore the response; from our POV, we're done
     }
 
     delete[] (char*)subsession.sessionId;
@@ -1834,11 +1834,7 @@ Boolean RTSPClient
         makeSocketNonBlocking(fInputSocketNum);
       }
       if (connect(fInputSocketNum, (struct sockaddr*) &remoteName, sizeof remoteName) != 0) {
-#if defined(__WIN32__) || defined(_WIN32)
-        if (errno != WSAEINPROGRESS && errno != WSAEWOULDBLOCK) {
-#else
-        if (errno != EINPROGRESS) {
-#endif
+        if (envir().getErrno() != EINPROGRESS && envir().getErrno() != EWOULDBLOCK) {
           envir().setResultErrMsg("connect() failed: ");
           break;
         }
